@@ -1,4 +1,7 @@
+__version__ = "0.1.3"
+
 from . import read as read
+from . import share as share
 from . import write as write
 from .boost import BoostExecutor as BoostExecutor
 from .copying import copyfile as copyfile
