@@ -25,7 +25,7 @@ class Request:
     headers: Mapping[str, str] = field(default_factory=dict, repr=False)
     success_codes: Sequence[int] = (200,)
     retry_codes: Sequence[int] = (408, 429, 500, 502, 503, 504)
-    failure_exceptions: Mapping[int, Exception] = field(default_factory=dict)
+    failure_exceptions: Mapping[int, Exception] = field(default_factory=dict, repr=False)
 
     @contextlib.asynccontextmanager
     async def execute(self) -> AsyncIterator[aiohttp.ClientResponse]:
@@ -40,7 +40,7 @@ class Request:
         """
 
         for attempt, backoff in enumerate(
-            _exponential_sleep_generator(
+            exponential_sleep_generator(
                 initial=config.backoff_initial,
                 maximum=config.backoff_max,
                 jitter_fraction=config.backoff_jitter_fraction,
@@ -76,8 +76,9 @@ class Request:
 
             print(
                 f"[boostedblob] Error when executing request on attempt {attempt}, sleeping for "
-                f"{backoff:.1f}s before retrying. Details: {error}"
-            )  # TODO: remove
+                f"{backoff:.1f}s before retrying. Details: {error}",
+                file=sys.stderr,
+            )
             await asyncio.sleep(backoff)
 
     async def execute_reponseless(self) -> None:
@@ -243,7 +244,7 @@ async def google_page_iterator(request: Request) -> AsyncIterator[Dict[str, Any]
 # ==============================
 
 
-def _exponential_sleep_generator(
+def exponential_sleep_generator(
     initial: float, maximum: float, jitter_fraction: float, multiplier: float = 2
 ) -> Iterator[float]:
     """Yields amounts to sleep by.
